import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
 * Demonstrates how to make modifications to an object's attributes.
 * It remove an attribute, adds an attribute value, and replaces
 * an attribute value.
 * After making the modifications, it replaces the object's attributes
 * with its original attributes.
 *
 * usage: java Modattrs
 */

class Modattrs {
    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	try {
	    // Create the initial context
	    DirContext ctx = new InitialDirContext(env);
	    String name = "cn=Ted Geisel, ou=People";

	    // Save original attributes
	    Attributes orig = ctx.getAttributes(name);

	    // Specify the changes to make
	    ModificationItem[] mods = new ModificationItem[3];

	    // Replace bowlingaverage attribute with new value
	    mods[0] = new ModificationItem(DirContext.REPLACE_ATTRIBUTE,
		new BasicAttribute("bowlingaverage", "300"));

	    // Add additional value to "telephonenumber"
	    mods[1] = new ModificationItem(DirContext.ADD_ATTRIBUTE,
		new BasicAttribute("telephonenumber", "+1 555 555 5555"));

	    // Remove jpegphoto
	    mods[2] = new ModificationItem(DirContext.REMOVE_ATTRIBUTE,
		new BasicAttribute("jpegphoto"));
	    
	    // Perform requested modifications on named object
	    ctx.modifyAttributes(name, mods);

	    // Check attributes
	    System.out.println("**** new attributes *****");
	    GetattrsAll.printAttrs(ctx.getAttributes(name));

	    // Revert changes
	    ctx.modifyAttributes(name, DirContext.REPLACE_ATTRIBUTE, orig);

	    // Check that attributes got restored
	    System.out.println("**** reverted to original attributes *****");
	    GetattrsAll.printAttrs(ctx.getAttributes(name));

	} catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
