import javax.naming.*;
import javax.naming.directory.*;
import javax.naming.spi.ObjectFactory;
import java.util.Hashtable;

/**
 * This is an object factory that when given a DirContext that
 * has the objectclass=drink attribute,
 * will create an instance of the corresponding Drink.
 */
public class DrinkFactory implements ObjectFactory {
    public DrinkFactory() {
    }

    public Object getObjectInstance(Object obj, Name name, Context ctx,
	Hashtable env) throws Exception {
	if (obj instanceof DirContext) {
	    DirContext thisCtx = (DirContext)obj;
	    try {
		Attributes attrs = thisCtx.getAttributes("");
//printAttrs(attrs);
		Attribute oc = attrs.get("objectclass");
		if (oc != null && oc.contains("drink")) {
		    Attribute dt = attrs.get("drinkType");
		    String drinkType = (String)dt.get();

		    return new Drink(drinkType);
		}
	    } catch (NamingException e) {
		// debug
		System.err.println(e);
		e.printStackTrace();
	    }
	}

	// return null to indicate other factories should be tried
	return null;
    }

    // for debugging
    static void printAttrs(Attributes attrs) {
	if (attrs == null) {
	    System.out.println("No attributes");
	} else {
	    /* print each attribute */
	    try {
		for (NamingEnumeration ae = attrs.getAll(); ae.hasMore();) {
		    Attribute attr = (Attribute)ae.next();
		    System.out.println("attribute: " + attr.getID());

		    /* print each value */
		    for (NamingEnumeration e = attr.getAll();
			 e.hasMore();
			 System.out.println("value: " + e.next()))
			;
		}
	    } catch (NamingException e) {
		e.printStackTrace();
	    }
	}
    }

}
